valuta.contrib.django\_integration package
==========================================

Submodules
----------

valuta.contrib.django\_integration.models module
------------------------------------------------

.. automodule:: valuta.contrib.django_integration.models
   :members:
   :undoc-members:
   :show-inheritance:

valuta.contrib.django\_integration.tests module
-----------------------------------------------

.. automodule:: valuta.contrib.django_integration.tests
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: valuta.contrib.django_integration
   :members:
   :undoc-members:
   :show-inheritance:
